@@ -1,28 +1,23 @@
 # -*- coding: utf-8 -*-
 """Define nonogram solver that uses contradictions"""
 
-from __future__ import unicode_literals, print_function
+from __future__ import print_function, unicode_literals
 
 import logging
 import time
-from collections import (
-    OrderedDict,
-    defaultdict,
-    deque,
-)
+from collections import OrderedDict, defaultdict, deque
 from itertools import product
 
 from six import iteritems
 from six.moves import range
 
-from pynogram.core import propagation
-from pynogram.core.board import (
-    CellPosition, CellState,
-)
-from pynogram.core.common import NonogramError
-from pynogram.core.line.base import cache_info
-from pynogram.utils.iter import expand_generator
-from pynogram.utils.priority_dict import PriorityDict
+from .board import CellPosition, CellState
+from .common import NonogramError
+from .line.base import cache_info
+from ..utils.iter import expand_generator
+from ..utils.priority_dict import PriorityDict
+
+from . import propagation
 
 LOG = logging.getLogger(__name__)
 
