@@ -15,25 +15,12 @@ from itertools import product
 
 from six.moves import range, zip
 
-from pynogram.core.color import ColorBlock
-from pynogram.core.common import (
-    UNKNOWN, BOX, SPACE, SPACE_COLORED,
-    BlottedBlock,
-    partial_sums,
-    slack_space,
-)
-from pynogram.core.line.base import (
-    BaseLineSolver,
-    TrimmedSolver,
-    NonogramError,
-)
-from pynogram.utils.iter import (
-    expand_generator,
-    max_continuous_interval,
-)
-from pynogram.utils.other import (
-    two_powers, from_two_powers,
-)
+from ...utils.iter import expand_generator, max_continuous_interval
+from ...utils.other import from_two_powers, two_powers
+from ..color import ColorBlock
+from ..common import (BOX, SPACE, SPACE_COLORED, UNKNOWN, BlottedBlock,
+                      partial_sums, slack_space)
+from .base import BaseLineSolver, NonogramError, TrimmedSolver
 
 LOG = logging.getLogger(__name__)
 
@@ -76,7 +63,8 @@ class BguSolver(BaseLineSolver):
             solved = self.solved_line
             if self._additional_space:
                 solved = solved[:-1]
-            solved = (UNKNOWN if cell == BOTH_COLORS else cell for cell in solved)
+            solved = (UNKNOWN if cell ==
+                      BOTH_COLORS else cell for cell in solved)
             return solved
 
         raise NonogramError('Bad line')
@@ -206,7 +194,8 @@ class BguSolver(BaseLineSolver):
             # finished placing the last block, exactly at the beginning of the line.
             return block == 0
 
-        can_be_solved = self.sol[block][position]  # self._get_sol(position, block)
+        # self._get_sol(position, block)
+        can_be_solved = self.sol[block][position]
         if can_be_solved is None:
             can_be_solved = self.fill_matrix_top_down(position, block)
 
@@ -422,7 +411,8 @@ class BlottedSolver(BaseLineSolver):
             return line
 
         blotted_desc, line = tuple(description), tuple(line)
-        LOG.warning('Solving line %r with blotted description %r', line, blotted_desc)
+        LOG.warning('Solving line %r with blotted description %r',
+                    line, blotted_desc)
 
         blotted_positions = [index for index, block in enumerate(blotted_desc)
                              if cls._is_blotted(block)]
@@ -439,12 +429,15 @@ class BlottedSolver(BaseLineSolver):
                 block = current_description[pos]
                 current_description[pos] = cls._update_block(block, block_size)
 
-            LOG.debug('Trying %i-th combination %r', index, current_description)
+            LOG.debug('Trying %i-th combination %r',
+                      index, current_description)
 
             try:
-                solved = tuple(super(BlottedSolver, cls).solve(current_description, line))
+                solved = tuple(super(BlottedSolver, cls).solve(
+                    current_description, line))
             except NonogramError:
-                LOG.debug('Combination %r is invalid for line %r', current_description, line)
+                LOG.debug('Combination %r is invalid for line %r',
+                          current_description, line)
             else:
                 solution = cls.merge_solutions(solved, solution)
                 LOG.debug('Merged solution: %s', solution)
@@ -455,7 +448,8 @@ class BlottedSolver(BaseLineSolver):
                     break
 
         if not solution:
-            raise NonogramError('Cannot solve with blotted clues {!r}'.format(blotted_desc))
+            raise NonogramError(
+                'Cannot solve with blotted clues {!r}'.format(blotted_desc))
 
         LOG.info('United solution from all combinations: %r', solution)
         assert len(solution) == len(line)
